@@ -117,7 +117,6 @@ class TrackingResult:
 
 @dataclass
 class MultipieceShipment:
-    tracking_number: str
     tracking_results: list
 
 
@@ -256,8 +255,7 @@ class FedexAPI:
             return TrackingResult(False)
         response_data = response.json()
         tracking_results = process_track_results(response_data)
-        tracking_number = tracking_results[0].tracking_number
-        mps = MultipieceShipment(str(tracking_number), tracking_results)
+        mps = MultipieceShipment(tracking_results)
         # if "errors" in response_data:
         #     return TrackingResult(False)
         return mps
